Function compress_to_utf16
Source pub fn compress_to_utf16(data: impl IntoWideIter) -> String
Compress a string as a valid String.
This function converts the result back into a Rust String since it is guaranteed to be valid UTF16.